from charms.reactive import when, when_not, when_any
from charms.reactive import set_flag, clear_flag
from charms.reactive import Endpoint


class CondaRequires(Endpoint):

    @when('endpoint.{endpoint_name}.joined')
    def joined(self):
        if any((unit.received['url'] and unit.received['sha']) for unit in self.all_units):
            set_flag(self.expand_name('endpoint.{endpoint_name}.available'))

    @when_not('endpoint.{endpoint_name}.joined')
    def broken(self):
        clear_flag(self.expand_name('endpoint.{endpoint_name}.available'))
        

    def relation_data(self):
        """
        Get the list of the relation info for each unit.

        """
        units_data = []
        for relation in self.relations:
            for unit in relation.units:
                sha = unit.received['sha']
                url = unit.received['url']
                conda_extra_packages = unit.received['conda_extra_packages']
                conda_extra_pip_packages = unit.received['conda_extra_pip_packages']
                ctxt = {
                    'sha': sha,
                    'url': url,
                }
                if conda_extra_packages:
                    ctxt['conda_extra_packages'] = conda_extra_packages
                if conda_extra_pip_packages:
                    ctxt['conda_extra_pip_packages'] = conda_extra_pip_packages
                units_data.append(ctxt)
        return units_data
